@@ -1,74 +1,29 @@
-/**********************************************************************
-This software program is available to you under a choice of one of two 
-licenses. You may choose to be licensed under either the GNU General Public 
-License (GPL) Version 2, June 1991, available at 
-http://www.fsf.org/copyleft/gpl.html, or the Intel BSD + Patent License, the 
-text of which follows:
+/*******************************************************************************
 
-Recipient has requested a license and Intel Corporation ("Intel") is willing
-to grant a license for the software entitled Linux Base Driver for the 
-Intel(R) PRO/100 Family of Adapters (e100) (the "Software") being provided 
-by Intel Corporation. The following definitions apply to this license:
-
-"Licensed Patents" means patent claims licensable by Intel Corporation which 
-are necessarily infringed by the use of sale of the Software alone or when 
-combined with the operating system referred to below.
-
-"Recipient" means the party to whom Intel delivers this Software.
-
-"Licensee" means Recipient and those third parties that receive a license to 
-any operating system available under the GNU Public License version 2.0 or 
-later.
-
-Copyright (c) 1999 - 2002 Intel Corporation.
-All rights reserved.
-
-The license is provided to Recipient and Recipient's Licensees under the 
-following terms.
-
-Redistribution and use in source and binary forms of the Software, with or 
-without modification, are permitted provided that the following conditions 
-are met:
-
-Redistributions of source code of the Software may retain the above 
-copyright notice, this list of conditions and the following disclaimer.
-
-Redistributions in binary form of the Software may reproduce the above 
-copyright notice, this list of conditions and the following disclaimer in 
-the documentation and/or materials provided with the distribution.
-
-Neither the name of Intel Corporation nor the names of its contributors 
-shall be used to endorse or promote products derived from this Software 
-without specific prior written permission.
-
-Intel hereby grants Recipient and Licensees a non-exclusive, worldwide, 
-royalty-free patent license under Licensed Patents to make, use, sell, offer 
-to sell, import and otherwise transfer the Software, if any, in source code 
-and object code form. This license shall include changes to the Software 
-that are error corrections or other minor changes to the Software that do 
-not add functionality or features when the Software is incorporated in any 
-version of an operating system that has been distributed under the GNU 
-General Public License 2.0 or later. This patent license shall apply to the 
-combination of the Software and any operating system licensed under the GNU 
-Public License version 2.0 or later if, at the time Intel provides the 
-Software to Recipient, such addition of the Software to the then publicly 
-available versions of such operating systems available under the GNU Public 
-License version 2.0 or later (whether in gold, beta or alpha form) causes 
-such combination to be covered by the Licensed Patents. The patent license 
-shall not apply to any other combinations which include the Software. NO 
-hardware per se is licensed hereunder.
-
-THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
-AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
-IMPLIED WARRANTIES OF MECHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
-ARE DISCLAIMED. IN NO EVENT SHALL INTEL OR IT CONTRIBUTORS BE LIABLE FOR ANY 
-DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
-(INCLUDING, BUT NOT LIMITED, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
-ANY LOSS OF USE; DATA, OR PROFITS; OR BUSINESS INTERUPTION) HOWEVER CAUSED 
-AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY OR 
-TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
-OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-**********************************************************************/
+  
+  Copyright(c) 1999 - 2002 Intel Corporation. All rights reserved.
+  
+  This program is free software; you can redistribute it and/or modify it 
+  under the terms of the GNU General Public License as published by the Free 
+  Software Foundation; either version 2 of the License, or (at your option) 
+  any later version.
+  
+  This program is distributed in the hope that it will be useful, but WITHOUT 
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
+  more details.
+  
+  You should have received a copy of the GNU General Public License along with
+  this program; if not, write to the Free Software Foundation, Inc., 59 
+  Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  
+  The full GNU General Public License is included in this distribution in the
+  file called LICENSE.
+  
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
+*******************************************************************************/
 
 /**********************************************************************
 *                                                                     *
@@ -90,7 +45,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ans_driver.h"
 #include "e100_config.h"
 
-
 /* bd_ans_drv_InitANS()
 **
 **  This function should be called at driver Init time to set the pointers
@@ -111,21 +65,19 @@ bd_ans_drv_InitANS(BOARD_PRIVATE_STRUCT *bps,
     /* set all the required status fields to this driver's 
      * status fields. */
     iANSdata->link_status =
-        (UINT32 *)&(((bd_config_t *)bps)->ans_link_status);
+        (UINT32 *)&(((struct e100_private *)bps)->ans_link_status);
     
     iANSdata->line_speed  =
-        (UINT32 *)&(((bd_config_t *)bps)->ans_line_speed);
+        (UINT32 *)&(((struct e100_private *)bps)->ans_line_speed);
     
     iANSdata->duplex      =
-        (UINT32 *)&(((bd_config_t *)bps)->ans_dplx_mode);
+        (UINT32 *)&(((struct e100_private *)bps)->ans_dplx_mode);
     
     iANSdata->hw_fail   = NULL;
     iANSdata->suspended = NULL;
     iANSdata->in_reset  = NULL;
 }
 
-
-
 /* bd_ans_drv_UpdateStatus()
 **
 **  This function should update the driver board status in the iANSsupport
@@ -149,20 +101,20 @@ bd_ans_drv_UpdateStatus(BOARD_PRIVATE_STRUCT *bps)
      * a status change.
      */
     /* this is done to convert to 32 bit values */
-    if (((bd_config_t *)bps)->flags & DF_LINK_UP) {
-        ((bd_config_t *)bps)->ans_link_status = IANS_STATUS_LINK_OK;
-        ((bd_config_t *)bps)->ans_line_speed = ((bd_config_t *)bps)->cur_line_speed;
-        ((bd_config_t *)bps)->ans_dplx_mode  = ((bd_config_t *)bps)->cur_dplx_mode;
+    if (netif_carrier_ok(((struct e100_private *)bps)->device)) {
+        ((struct e100_private *)bps)->ans_link_status = IANS_STATUS_LINK_OK;
+        ((struct e100_private *)bps)->ans_line_speed =
+		((struct e100_private *)bps)->cur_line_speed;
+        ((struct e100_private *)bps)->ans_dplx_mode  =
+		((struct e100_private *)bps)->cur_dplx_mode;
     } else {
-        ((bd_config_t *)bps)->ans_link_status = IANS_STATUS_LINK_FAIL;
-        ((bd_config_t *)bps)->ans_line_speed = 0;
-        ((bd_config_t *)bps)->ans_dplx_mode = 0;
+        ((struct e100_private *)bps)->ans_link_status = IANS_STATUS_LINK_FAIL;
+        ((struct e100_private *)bps)->ans_line_speed = 0;
+        ((struct e100_private *)bps)->ans_dplx_mode = 0;
     }
     return;
 }
 
-
-
 /* bd_ans_drv_ConfigureTagging()
 **
 **  This function will call the HW specific functions to configure
@@ -177,13 +129,12 @@ bd_ans_drv_UpdateStatus(BOARD_PRIVATE_STRUCT *bps)
 BD_ANS_STATUS 
 bd_ans_drv_ConfigureTagging(BOARD_PRIVATE_STRUCT *bdp)
 {
-
+    
     /* no hw action should ne taken to turn general tagging on/off */
     return BD_ANS_SUCCESS;
     
 }
 
-
 /* bd_ans_drv_ConfigureVlanTable()
 **
 **  This function will call the HW specific functions to configure the
@@ -202,7 +153,6 @@ bd_ans_drv_ConfigureVlanTable(BOARD_PRIVATE_STRUCT *bps)
     return BD_ANS_FAILURE;
 }
 
-
 /* bd_ans_drv_ConfigureVlan()
 **
 **  This function will call the HW specific functions to configure the
@@ -229,10 +179,10 @@ bd_ans_drv_ConfigureVlan(BOARD_PRIVATE_STRUCT *bps)
         
 #ifdef IANS_BASE_VLAN_TAGGING
         if (iANSdata->vlan_mode == IANS_VLAN_MODE_ON) {
-            e100_config_enable_tagging(bps, B_TRUE);
+            e100_config_enable_tagging(bps, true);
             
         } else {
-            e100_config_enable_tagging(bps, B_FALSE);
+            e100_config_enable_tagging(bps, false);
         }
 #endif
     }
@@ -240,7 +190,6 @@ bd_ans_drv_ConfigureVlan(BOARD_PRIVATE_STRUCT *bps)
     return e100_config(bps) ? BD_ANS_SUCCESS : BD_ANS_FAILURE;
 }
 
-
 /* bd_ans_drv_StopWatchdog()
 **
 **  Since the linux driver already has a watchdog routine, we just need to
@@ -261,7 +210,6 @@ bd_ans_drv_StopWatchdog(BOARD_PRIVATE_STRUCT *bps)
     ANS_PRIVATE_DATA_FIELD(bps)->reporting_mode = IANS_STATUS_REPORTING_OFF;
 }
 
-
 /* bd_ans_drv_StopPromiscuousMode()
 **
 **  The linux driver does not support this.
@@ -272,7 +220,6 @@ bd_ans_drv_StopPromiscuousMode(BOARD_PRIVATE_STRUCT *bps)
     return BD_ANS_FAILURE;
 }
 
-
 /* bd_ans_drv_StartWatchdog()
 **
 **  Since the linux driver already has a watchdog routine started,
@@ -297,6 +244,3 @@ bd_ans_drv_StartWatchdog(BOARD_PRIVATE_STRUCT *bps)
     return 1;
 }
 
-
-
-
